
from .galpak3d import GalPaK3D
from .disk_model import  DiskModel

def run(cube,
        variance=None,
        seeing=None, line=None, instrument=None,
        verbose=True,
        crval3=None, crpix3=None, cunit3=None, cdelt3=None, ctype3=None, cunit1=None,
        force_header_update=False,
        max_iterations=15000,
        method_chain='last',
        last_chain_fraction=30,
        percentile=95,
        model=DiskModel(),
        flux_image=None,
        chi_stat = 'gaussian',
        min_boundaries=None,
        max_boundaries=None,
        known_parameters=None,
        initial_parameters=None,
        min_acceptance_rate=5.0,
        random_scale=None):
    """
    Creates a GalPaK3D instance and runs it on provided cube.
    Refer to documentations of GalPaK3D and GalPaK3D.run_mcmc().

    Use like this: ::

        import galpak
        g = galpak.run(cube='my.fits')

        print g.galaxy
        g.save('my_run')
        # etc.
    """
    g = GalPaK3D(cube, variance=variance,   seeing=seeing,
                 line=line, instrument=instrument,
                 crval3=crval3, crpix3=crpix3, cunit3=cunit3, cdelt3=cdelt3,
                 ctype3=ctype3, cunit1=cunit1,
                 force_header_update=force_header_update)
    g.run_mcmc(verbose=verbose,
		max_iterations=max_iterations,
               method_chain=method_chain,
               last_chain_fraction=last_chain_fraction,
               percentile=percentile,
               model=model,
               flux_image=flux_image,
               chi_stat=chi_stat,
               min_boundaries=min_boundaries,
               max_boundaries=max_boundaries,
               known_parameters=known_parameters,
               initial_parameters=initial_parameters,
               min_acceptance_rate=min_acceptance_rate,
               random_scale=random_scale)

    return g
